/*****************************************************************************
 * extstdlib.cpp - Source file for basic program standard library            *
 * (libextstd.so) or (libextstd.a) - Version 0.4                             *
 * ------------------------------------------------------------------------- *
 * Copyright 2002-2006 by Rosario M. Piro (devfaust@users.sourceforge.net)   *
 *                                                                           *
 *   This program is free software; you can redistribute it and/or modify    *
 *   it under the terms of the GNU General Public License as published by    *
 *   the Free Software Foundation; either version 2 of the License, or       *
 *   (at your option) any later version.                                     *
 *                                                                           *
 *   This program is distributed in the hope that it will be useful,         *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *   GNU General Public License for more details.                            *
 *                                                                           *
 *   You should have received a copy of the GNU General Public License       *
 *   along with this program; if not, write to the Free Software             *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA *
 *   or see http://www.gnu.org/copyleft/gpl.html                             *
 * ------------------------------------------------------------------------- */

/*********************/
/*** include files ***/
/*********************/
#include "extstdlib.h"
#include <ctype.h>


/************************/
/*** global variables ***/
/************************/
bool isInteractive = TRUE;
bool isVerbose = FALSE;


/****************************/
/*** function definitions ***/
/****************************/

/* check if a double value is approximately equal to zero */ 
bool isZero(double value, double accuracy) {
  if ( (value<accuracy) && (value>-accuracy) )
    return TRUE;
  else
    return FALSE;
}

bool isZero(double value) {
  return isZero(value, EPSILON);
}

string int2string(int i) {
  ostringstream oss;
  oss << i;
  return oss.str();
}

string double2string(double d) {
  ostringstream oss;
  oss << d;
  return oss.str();
}


/* check whether an entire string is numeric (digit), alphanumeric, etc. */
/* accept scientific notation with 'e' or 'E' for exponent */
bool isNumeric(const char *str) {

  // first character can be '-' or digit!
  if ( str[0] == '\0' || (str[0] != '-' && !isdigit(str[0])) )
    return false;

  int i;
  for (i = 1; str[i] != '\0'; i++) {
    if (!isdigit(str[i]) && (str[i] != '.') && (str[i] != 'e')
        && (str[i] != 'E') && (str[i] != '-'))
      return false;
  }
  return true;
} // isNumeric() ...


//*********************/
//*** splitString() ***/
//*********************/
int splitString(const string str, const char delimiter,
		vector<string> &strTokens) {

  int retVal = 0; // ok

  unsigned long int index1 = 0;
  unsigned long int index2 = 0;
  string token;

  while ( (index2=str.find(delimiter,index1)) != string::npos ) {
    token = str.substr(index1, index2-index1);
    strTokens.push_back(token);
    index1 = ++index2;
  }

  if (index1 != string::npos) {
    // last token, until end ...
    token = str.substr(index1);
    strTokens.push_back(token);
  }
  else {
    retVal = 1; // strange ...
  }

  return retVal; // ok?

} // splitString() ...
